==> php-residence_0.2.4.tar.gz: php-residence/includes/lang/en/visualizza_tabelle.php <==
<?php

switch ($messaggio) {

case "Vedi le prenotazioni":  			$messaggio = "View the reservations"; break;
case "presenti dal":  				$messaggio = "present from"; break;
case "al":  					$messaggio = "to"; break;
case "Senza colori":  				$messaggio = "Without colors"; break;
case "Con colori":  				$messaggio = "With colors"; break;
case "Tabella prenotazioni precedenti al":  	$messaggio = "Table with reservations previous to"; break;
case "Tabella prenotazioni successive al":  	$messaggio = "Table with reservations subsequent"; break;
case "Tabella con tutte le prenotazioni del":  	$messaggio = "Table with all the reservations of"; break;
case "Cognome_cliente":  			$messaggio = "Client_surname"; break;
case "Data_iniziale":  				$messaggio = "Strarting_date"; break;
case "Data_finale":  				$messaggio = "Ending_date"; break;
case "sett":  					$messaggio = "W"; break;
case "gio":  					$messaggio = "D"; break;
case "Tariffa_completa":  			$messaggio = "Complete_fare"; break;
case "Caparra":  				$messaggio = "Deposit"; break;
case "Pagato":  				$messaggio = "Paid"; break;
case "Da_pagare":  				$messaggio = "To_pay"; break;
case "App":  					$messaggio = "Apa"; break;
case "Pers":  					$messaggio = "Peop"; break;
case "Commento":  				$messaggio = "Comment"; break;
case "Costo_fin.":  				$messaggio = "Sing._cost"; break;
case "Costo_sett.":  				$messaggio = "Week._cost"; break;
case "Costo_gio.":  				$messaggio = "Daily_cost"; break;
case "Costo_perc.":  				$messaggio = "Perc._cost"; break;
case "Soldi di prenotazioni cancellate":  	$messaggio = "Money of deleted reservations"; break;
case "TOTALE":  				$messaggio = "TOTAL"; break;
case "Trasferito in cassa":  			$messaggio = "Transferred in cash box"; break;
case "RESTO":  					$messaggio = "REST"; break;
case "Sei sicuro di voler cancellare la spesa":	$messaggio = "Are you sure you want to delete cash payment"; break;
case "del valore di":  				$messaggio = "of"; break;
case "Sei sicuro di voler cancellare l'entrata":	$messaggio = "Are you sure you want to delete cash receipt"; break;
case "SI":  					$messaggio = "YES"; break;
case "NO":  					$messaggio = "NO"; break;
case "Entrata o spesa":  			$messaggio = "Cash payment or receipt"; break;
case "cacellata":  				$messaggio = "deleted"; break;
case "Costo o spesa gi cancellati":  		$messaggio = "Cash payment or receipt already deleted"; break;
case "Tabella con tutte le spese del":  	$messaggio = "Table with all the cash payments of"; break;
case "Natura_spesa":  				$messaggio = "Reason_for_payment"; break;
case "Importo":  				$messaggio = "Value"; break;
case "Inserita_da":  				$messaggio = "Inserted_by"; break;
case "Data_di_inserimento":  			$messaggio = "Insertion_date"; break;
case "Cancella":  				$messaggio = "Delete"; break;
case "Tabella con tutte le entrate del":  	$messaggio = "Table with all the cash receipts of"; break;
case "Natura_entrata":  			$messaggio = "Reason_for_receipt"; break;
case "cancella":  				$messaggio = "delete"; break;
case "entrata presa dalle prenotazioni":  	$messaggio = "Cash receipt taken from reservations"; break;
case "Totale in cassa":  			$messaggio = "Total in cash box"; break;
case "Inserisci nuove spese o entrate":  	$messaggio = "Insert new cash receipts or payments"; break;
case "Storia entrate-uscite prenotazioni":  	$messaggio = "History of reservations payments"; break;
case "Sei sicuro di voler cancellare il costo aggiuntivo":	$messaggio = "Are you sure you want to delete extra cost"; break;
case "Il costo aggiuntivo":  			$messaggio = "The extra cost"; break;
case "Il costo aggiuntivo  cambiato nel frattempo, non  stao cancellato":	$messaggio = "The extra cost was changed meanwhile, it has not been deleted"; break;
case " stato cancellato":  			$messaggio = "has been deleted"; break;
case "I periodi sono stati aggiunti fino al":  	$messaggio = "Periods have been added until"; break;
case "Tabella con periodi e relative tariffe del":	$messaggio = "Table with periods and respective fares of"; break;
case "tariffa":  				$messaggio = "fare"; break;
case "Inizio_settimana":  			$messaggio = "Starting_week"; break;
case "Inizio_giorno":  				$messaggio = "Starting_day"; break;
case "Fine_settimana":  			$messaggio = "Ending_week"; break;
case "Fine_giorno":  				$messaggio = "Ending_day"; break;
case "Aggiungi periodi":  			$messaggio = "Add periods"; break;
case "fino al mese":  				$messaggio = "until month"; break;
case "Tabella con i costi aggiuntivi del":  	$messaggio = "Table with extra costs of"; break;
case "Nome":  					$messaggio = "Name"; break;
case "Tipo":  					$messaggio = "Type"; break;
case "Prezzo":  				$messaggio = "Value"; break;
case "Da_assegnare":  				$messaggio = "To_assign"; break;
case "finale":  				$messaggio = "single"; break;
case "Sempre":  				$messaggio = "Always"; break;
case "Su_richiesta":  				$messaggio = "On_demand"; break;
case "chidere_per_quanto_moltiplicare":  	$messaggio = "ask_by_how_much_multiply"; break;
case "cosiderare_come_letti_aggiuntivi":  	$messaggio = "consider_as_extra_beds"; break;
case "settimanale":  				$messaggio = "weekly"; break;
case "giornaliero":  				$messaggio = "daily"; break;
case " tutte":  				$messaggio = " all"; break;
case " tutti":  				$messaggio = " all"; break;
case "_le":  					$messaggio = "_the"; break;
case "_i":  					$messaggio = "_the"; break;
case "_settimane":  				$messaggio = "_weeks"; break;
case "_giorni":  				$messaggio = "_days"; break;
case "_meno_una":  				$messaggio = "_minus_one"; break;
case " con_n_di_settimane":  			$messaggio = " asking_the_number_of_weeks"; break;
case " con_n_di_giorni":  			$messaggio = " asking_the_number_of_days"; break;
case "_da_chiedere":  				$messaggio = ""; break;
case "percentuale":  				$messaggio = "percentage"; break;
case "% arrotondato_a_":  			$messaggio = "% rounded_to_"; break;
case "Caparra del":  				$messaggio = "Deposit of"; break;
case "Percentuale_sul_totale":  		$messaggio = "Percentage_of_the_total"; break;
case "Arrotondata_a":  				$messaggio = "Rounded_to"; break;
case "Vai alla pagina di inserzione prezzi":  	$messaggio = "Go to the prices insertion page"; break;
case "chiamati":  				$messaggio = "named"; break;
case "Cerca i clienti con cognome":  		$messaggio = "Search for clients with surname"; break;
case "Tabella con tutti i clienti":  		$messaggio = "Table with all the clients"; break;
case "pag. prec.":  				$messaggio = "prev. page"; break;
case "pag. succ.":  				$messaggio = "next page"; break;
case "Cognome":  				$messaggio = "Surname"; break;
case "Nome":  					$messaggio = "Name"; break;
case "Telefono":  				$messaggio = "Telephone"; break;
case "Indirizzo":  				$messaggio = "Address"; break;
case "Citt":  					$messaggio = "City"; break;
case "Nazione":  				$messaggio = "Nation"; break;
case "CAP":  					$messaggio = "Pos. code"; break;
case "Fax":  					$messaggio = "Fax"; break;
case "Email":  					$messaggio = "Email"; break;
case "Data_di_nascita":  			$messaggio = "Birthday"; break;
case "2telefono":  				$messaggio = "2nd phone"; break;
case "Commento":  				$messaggio = "Comment"; break;
case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 1 dell'appartamento":	$messaggio = "Are you sure you want to <b>delete</b> the assignation rule 1 for the apartment"; break;
case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 2 per la":	$messaggio = "Are you sure you want to <b>delete</b> the assignation rule 2 for"; break;
case "La regola di assegnazione  stata cancellata":	$messaggio = "The assignation rule has been deleted"; break;
case "La regola di assegnazione  gi stata cancellata":	$messaggio = "The assignation rule has already been deleted"; break;
case "Tabella con la regole di assegnazione 1 del":	$messaggio = "Table with the assignation rules 1 of"; break;
case "Motivazione":  				$messaggio = "Motivation"; break;
case "Appartamento":  				$messaggio = "Apartment"; break;
case "Tabella con la regole di assegnazione 2 del":	$messaggio = "Table with the assignation rules 2 of"; break;
case "Appartamenti":  				$messaggio = "Apartments"; break;
case "Tariffa":  				$messaggio = "Fare"; break;
case "Inserisci nuove regole":  		$messaggio = "Insert new rules"; break;
case "Si deve inserire il numero del nuovo appartamento":	$messaggio = "You must insert the number of the new apartment"; break;
case "Il numero inserito esiste gi":  		$messaggio = "The inserted number already exists"; break;
case "verr aggiunto":  			$messaggio = "will be added"; break;
case "L'appatramento":  			$messaggio = "Apartment"; break;
case "Continua":  				$messaggio = "Continue"; break;
case "Torna indietro":  			$messaggio = "Go back"; break;
case " stato aggiunto":  			$messaggio = "has been added"; break;
case "Tabella con tutti gli appartamenti":  	$messaggio = "Table with all the apartments"; break;
case "Casa":  					$messaggio = "House"; break;
case "Piano":  					$messaggio = "Floor"; break;
case "Capienza_massima":  			$messaggio = "Maximum_capacity"; break;
case "Priorit":  				$messaggio = "Priority"; break;
case "Modifica":  				$messaggio = "Modify"; break;
case "modifica":  				$messaggio = "modify"; break;
case "Crea un nuovo appartamento":  		$messaggio = "Create new apartment"; break;
case "Torna al men principale":  		$messaggio = "Back to main menu"; break;
case "persone":  				$messaggio = "people"; break;
case "s":  					$messaggio = "w"; break;
case "g":  					$messaggio = "d"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> php-residence_0.3.tar.gz: php-residence/includes/lang/en/visualizza_tabelle.php <==
<?php

switch ($messaggio) {

case "Vedi le prenotazioni":  			$messaggio = "View the reservations"; break;
case "presenti dal":  				$messaggio = "present from"; break;
case "al":  					$messaggio = "to"; break;
case "Senza colori":  				$messaggio = "Without colors"; break;
case "Con colori":  				$messaggio = "With colors"; break;
case "Tabella prenotazioni precedenti al":  	$messaggio = "Table with reservations previous to"; break;
case "Tabella prenotazioni successive al":  	$messaggio = "Table with reservations subsequent"; break;
case "Tabella con tutte le prenotazioni del":  	$messaggio = "Table with all the reservations of"; break;
case "Cognome_cliente":  			$messaggio = "Client_surname"; break;
case "Data_iniziale":  				$messaggio = "Strarting_date"; break;
case "Data_finale":  				$messaggio = "Ending_date"; break;
case "sett":  					$messaggio = "W"; break;
case "gio":  					$messaggio = "D"; break;
case "Tariffa_completa":  			$messaggio = "Complete_fare"; break;
case "Caparra":  				$messaggio = "Deposit"; break;
case "Pagato":  				$messaggio = "Paid"; break;
case "Da_pagare":  				$messaggio = "To_pay"; break;
case "App":  					$messaggio = "Apa"; break;
case "Pers":  					$messaggio = "Peop"; break;
case "Commento":  				$messaggio = "Comment"; break;
case "Costo_fin.":  				$messaggio = "Sing._cost"; break;
case "Costo_sett.":  				$messaggio = "Week._cost"; break;
case "Costo_gio.":  				$messaggio = "Daily_cost"; break;
case "Costo_perc.":  				$messaggio = "Perc._cost"; break;
case "Soldi di prenotazioni cancellate":  	$messaggio = "Money of deleted reservations"; break;
case "TOTALE":  				$messaggio = "TOTAL"; break;
case "Trasferito in cassa":  			$messaggio = "Transferred in cash box"; break;
case "RESTO":  					$messaggio = "REST"; break;
case "Sei sicuro di voler cancellare la spesa":	$messaggio = "Are you sure you want to delete cash payment"; break;
case "del valore di":  				$messaggio = "of"; break;
case "Sei sicuro di voler cancellare l'entrata":	$messaggio = "Are you sure you want to delete cash receipt"; break;
case "SI":  					$messaggio = "YES"; break;
case "NO":  					$messaggio = "NO"; break;
case "Entrata o spesa":  			$messaggio = "Cash payment or receipt"; break;
case "cacellata":  				$messaggio = "deleted"; break;
case "Costo o spesa gi cancellati":  		$messaggio = "Cash payment or receipt already deleted"; break;
case "Tabella con tutte le spese del":  	$messaggio = "Table with all the cash payments of"; break;
case "Natura_spesa":  				$messaggio = "Reason_for_payment"; break;
case "Importo":  				$messaggio = "Value"; break;
case "Inserita_da":  				$messaggio = "Inserted_by"; break;
case "Data_di_inserimento":  			$messaggio = "Insertion_date"; break;
case "Cancella":  				$messaggio = "Delete"; break;
case "Tabella con tutte le entrate del":  	$messaggio = "Table with all the cash receipts of"; break;
case "Natura_entrata":  			$messaggio = "Reason_for_receipt"; break;
case "cancella":  				$messaggio = "delete"; break;
case "entrata presa dalle prenotazioni":  	$messaggio = "Cash receipt taken from reservations"; break;
case "Totale in cassa":  			$messaggio = "Total in cash box"; break;
case "Inserisci nuove spese o entrate":  	$messaggio = "Insert new cash receipts or payments"; break;
case "Storia entrate-uscite prenotazioni":  	$messaggio = "History of reservations payments"; break;
case "Sei sicuro di voler cancellare il costo aggiuntivo":	$messaggio = "Are you sure you want to delete extra cost"; break;
case "Il costo aggiuntivo":  			$messaggio = "The extra cost"; break;
case "Il costo aggiuntivo  cambiato nel frattempo, non  stao cancellato":	$messaggio = "The extra cost was changed meanwhile, it has not been deleted"; break;
case " stato cancellato":  			$messaggio = "has been deleted"; break;
case "I periodi sono stati aggiunti fino al":  	$messaggio = "Periods have been added until"; break;
case "Tabella con periodi e relative tariffe del":	$messaggio = "Table with periods and respective fares of"; break;
case "tariffa":  				$messaggio = "fare"; break;
case "Inizio_settimana":  			$messaggio = "Starting_week"; break;
case "Inizio_giorno":  				$messaggio = "Starting_day"; break;
case "Fine_settimana":  			$messaggio = "Ending_week"; break;
case "Fine_giorno":  				$messaggio = "Ending_day"; break;
case "Aggiungi periodi":  			$messaggio = "Add periods"; break;
case "fino al mese":  				$messaggio = "until month"; break;
case "Tabella con i costi aggiuntivi del":  	$messaggio = "Table with extra costs of"; break;
case "Nome":  					$messaggio = "Name"; break;
case "Tipo":  					$messaggio = "Type"; break;
case "Prezzo":  				$messaggio = "Value"; break;
case "Da_assegnare":  				$messaggio = "To_assign"; break;
case "finale":  				$messaggio = "single"; break;
case "Sempre":  				$messaggio = "Always"; break;
case "Su_richiesta":  				$messaggio = "On_demand"; break;
case "chidere_per_quanto_moltiplicare":  	$messaggio = "ask_by_how_much_multiply"; break;
case "cosiderare_come_letti_aggiuntivi":  	$messaggio = "consider_as_extra_beds"; break;
case "settimanale":  				$messaggio = "weekly"; break;
case "giornaliero":  				$messaggio = "daily"; break;
case " tutte":  				$messaggio = " all"; break;
case " tutti":  				$messaggio = " all"; break;
case "_le":  					$messaggio = "_the"; break;
case "_i":  					$messaggio = "_the"; break;
case "_settimane":  				$messaggio = "_weeks"; break;
case "_giorni":  				$messaggio = "_days"; break;
case "_meno_una":  				$messaggio = "_minus_one"; break;
case " con_n_di_settimane":  			$messaggio = " asking_the_number_of_weeks"; break;
case " con_n_di_giorni":  			$messaggio = " asking_the_number_of_days"; break;
case "_da_chiedere":  				$messaggio = ""; break;
case "percentuale":  				$messaggio = "percentage"; break;
case "% arrotondato_a_":  			$messaggio = "% rounded_to_"; break;
case "Caparre del":  				$messaggio = "Deposits of"; break;
case "Percentuale_sul_totale":  		$messaggio = "Percentage_of_the_total"; break;
case "Arrotondata_a":  				$messaggio = "Rounded_to"; break;
case "Vai alla pagina di inserzione prezzi":  	$messaggio = "Go to the prices insertion page"; break;
case "chiamati":  				$messaggio = "named"; break;
case "Cerca i clienti con cognome":  		$messaggio = "Search for clients with surname"; break;
case "Tabella con tutti i clienti":  		$messaggio = "Table with all the clients"; break;
case "pag. prec.":  				$messaggio = "prev. page"; break;
case "pag. succ.":  				$messaggio = "next page"; break;
case "Cognome":  				$messaggio = "Surname"; break;
case "Nome":  					$messaggio = "Name"; break;
case "Telefono":  				$messaggio = "Telephone"; break;
case "Indirizzo":  				$messaggio = "Address"; break;
case "Citt":  					$messaggio = "City"; break;
case "Nazione":  				$messaggio = "Nation"; break;
case "CAP":  					$messaggio = "Pos. code"; break;
case "Fax":  					$messaggio = "Fax"; break;
case "Email":  					$messaggio = "Email"; break;
case "Data_di_nascita":  			$messaggio = "Birthday"; break;
case "2telefono":  				$messaggio = "2nd phone"; break;
case "Commento":  				$messaggio = "Comment"; break;
case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 1 dell'appartamento":	$messaggio = "Are you sure you want to <b>delete</b> the assignation rule 1 for the apartment"; break;
case "Sei sicuro di voler <b>cancellare</b> la regola di assegnazione 2 per la":	$messaggio = "Are you sure you want to <b>delete</b> the assignation rule 2 for"; break;
case "La regola di assegnazione  stata cancellata":	$messaggio = "The assignation rule has been deleted"; break;
case "La regola di assegnazione  gi stata cancellata":	$messaggio = "The assignation rule has already been deleted"; break;
case "Tabella con la regole di assegnazione 1 del":	$messaggio = "Table with the assignation rules 1 of"; break;
case "Motivazione":  				$messaggio = "Motivation"; break;
case "Appartamento":  				$messaggio = "Apartment"; break;
case "Tabella con la regole di assegnazione 2 del":	$messaggio = "Table with the assignation rules 2 of"; break;
case "Appartamenti":  				$messaggio = "Apartments"; break;
case "Tariffa":  				$messaggio = "Fare"; break;
case "Inserisci nuove regole":  		$messaggio = "Insert new rules"; break;
case "Si deve inserire il numero del nuovo appartamento":	$messaggio = "You must insert the number of the new apartment"; break;
case "Il numero inserito esiste gi":  		$messaggio = "The inserted number already exists"; break;
case "verr aggiunto":  			$messaggio = "will be added"; break;
case "L'appatramento":  			$messaggio = "Apartment"; break;
case "Continua":  				$messaggio = "Continue"; break;
case "Torna indietro":  			$messaggio = "Go back"; break;
case " stato aggiunto":  			$messaggio = "has been added"; break;
case "Tabella con tutti gli appartamenti":  	$messaggio = "Table with all the apartments"; break;
case "Casa":  					$messaggio = "House"; break;
case "Piano":  					$messaggio = "Floor"; break;
case "Capienza_massima":  			$messaggio = "Maximum_capacity"; break;
case "Priorit":  				$messaggio = "Priority"; break;
case "Modifica":  				$messaggio = "Modify"; break;
case "modifica":  				$messaggio = "modify"; break;
case "Crea un nuovo appartamento":  		$messaggio = "Create new apartment"; break;
case "Torna al men principale":  		$messaggio = "Back to main menu"; break;
case "persone":  				$messaggio = "people"; break;
case "s":  					$messaggio = "w"; break;
case "g":  					$messaggio = "d"; break;
case "Mostra":  				$messaggio = "Display"; break;
case "Non_mostrare":  				$messaggio = "Do_not_display"; break;
case "Regole":  				$messaggio = "Rules"; break;
case "Tariffe abbinate":  			$messaggio = "Associated fares"; break;
case "pagine":  				$messaggio = "pages"; break;
case "Verranno effettuati i seguenti cambiamenti":	$messaggio = "I will make this changes"; break;
case "I soldi pagati per la prenotazione":  	$messaggio = "Money paid for reservation"; break;
case "a nome di":  				$messaggio = "for Mr/Mrs"; break;
case "verranno cambiati da":  			$messaggio = "will be changed from"; break;
case "a":  					$messaggio = "to"; break;
case "differenza":  				$messaggio = "difference"; break;
case "Le prenotazioni <b>non sono state modificate</b> perch sono cambiate nel frattempo":	$messaggio = "The reservations <b>have not been modified</b> because the reservations table changed meanwhile"; break;
case "Cambia le prenotazioni selezionate":  	$messaggio = "Change selected reservations"; break;
case "ponendo":  				$messaggio = "to"; break;
case "tutto pagato":  				$messaggio = "all paid"; break;
case "caparra pagata":  			$messaggio = "deposit paid"; break;
case "pagato niente":  				$messaggio = "nothing paid"; break;
case "pagina":  				$messaggio = "page"; break;
case "di":  					$messaggio = "of"; break;
case "la conferma":  				$messaggio = "confirmed"; break;
case "La prenotazione":  			$messaggio = "The reservation"; break;
case "verr confermata":  			$messaggio = "will be confirmed"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
